@@ -12,6 +12,8 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import datetime
+
 from oslo.config import cfg
 from oslo.db.sqlalchemy import session as db_session
 from oslo.db.sqlalchemy import utils as db_utils
@@ -584,6 +586,30 @@ def get_test_run_time_series(test_id, session=None):
     return time_series
 
 
+def get_test_status_time_series(test_id, session=None):
+    """Returns a time series dict of test_run statuses of a single test
+
+    :param str test_id: The test's uuid (the id column in the test table) which
+                        will be used to get all the test run times for.
+    :param session: optional session object if one isn't provided a new session
+
+    :return dict: A dictionary with the start times as the keys and the values
+                  being the status of that test run.
+    """
+    session = session or get_session()
+    query = db_utils.model_query(models.TestRun, session=session).filter_by(
+        test_id=test_id).values(
+            models.TestRun.start_time, models.TestRun.start_time_microsecond,
+            models.TestRun.status)
+    status_series = {}
+    for test_run in query:
+        start_time = test_run[0]
+        start_time = start_time.replace(microsecond=test_run[1])
+        status = test_run[2]
+        status_series[start_time] = status
+    return status_series
+
+
 def get_recent_successful_runs(num_runs=10, session=None):
     """Return a list of run uuid strings for the most recent successful runs
 
@@ -613,3 +639,110 @@ def get_recent_failed_runs(num_runs=10, session=None):
         models.Run.run_at.desc()).filter(
         models.Run.fails > 0).limit(num_runs).all()
     return map(lambda x: x.id, results)
+
+
+def delete_old_runs(expire_age=186, session=None):
+    """Delete all runs and associated metadata older than the provided age
+
+    :param int expire_age: The number of days into the past to use as the
+                           expiration date for deleting the runs
+    :param session: optional session object if one isn't provided a new session
+    """
+    session = session or get_session()
+    expire_date = datetime.date.today() - datetime.timedelta(days=expire_age)
+    db_utils.model_query(models.Run, session).filter(
+        models.Run.run_at < expire_date).join(
+            models.RunMetadata).delete(synchronize_session='evaluate')
+    db_utils.model_query(models.Run, session).filter(
+        models.Run.run_at < expire_date).delete(synchronize_session='evaluate')
+
+
+def delete_old_test_runs(expire_age=186, session=None):
+    """Delete all test runs and associated metadata older than the provided age
+
+    :param int expire_age: The number of days into the past to use as the
+                           expiration date for deleting the test runs
+    :param session: optional session object if one isn't provided a new session
+    """
+    session = session or get_session()
+    expire_date = datetime.date.today() - datetime.timedelta(days=expire_age)
+    db_utils.model_query(models.TestRun, session).filter(
+        models.TestRun.start_time < expire_date).join(
+            models.TestRunMetadata).delete(synchronize_session='evaluate')
+    db_utils.model_query(models.TestRun, session).filter(
+        models.TestRun.start_time < expire_date).delete(
+            synchronize_session='evaluate')
+
+
+def get_id_from_test_id(test_id, session=None):
+    """Return the id (uuid primary key) for a test given it's test_id value
+
+    :param str test_id:
+    :param session: optional session object if one isn't provided a new session
+                    will be acquired for the duration of this operation
+    :return: The id for the specified test
+    :rtype: str
+    """
+    session = session or get_session()
+    return db_utils.model_query(models.Test, session).filter_by(
+        test_id=test_id).value('id')
+
+
+def get_ids_for_all_tests(session=None):
+    """Return a list of ids (uuid primary key) for all tests in the database
+
+    :param session: optional session object if one isn't provided a new session
+                    will be acquired for the duration of this operation
+    :return: The list of all ids for tests in the tests table
+    :rtype: list
+    """
+    session = session or get_session()
+    return db_utils.model_query(models.Test, session).value(models.Test.id)
+
+
+def get_test_counts_in_date_range(test_id, start_date=None, stop_date=None,
+                                  session=None):
+    """Return the number of successes, failures, and skips for a single test.
+
+    Optionally you can provide a date to filter the results to be within a
+    certain date range
+
+    :param str start_date: The date to use as the start for counting
+    :param str stop_date: The date to use as the cutoff for counting
+    :param session: optional session object if one isn't provided a new session
+                    will be acquired for the duration of this operation
+    :return: a dict containing the number of successes, failures, and skips
+    :rtype: dict
+    """
+    start_date = datetime.datetime.strptime(start_date, '%b %d %Y')
+    if isinstance(stop_date, str):
+        stop_date = datetime.datetime.strptime(stop_date, '%b %d %Y')
+    session = session or get_session()
+    count_dict = {}
+    success_query = db_utils.model_query(models.TestRun, session).filter_by(
+        test_id=test_id).filter(models.TestRun.status == 'success')
+    fail_query = db_utils.model_query(models.TestRun, session).filter_by(
+        test_id=test_id).filter(models.TestRun.status == 'fail')
+    skip_query = db_utils.model_query(models.TestRun, session).filter_by(
+        test_id=test_id).filter(models.TestRun.status == 'skip')
+
+    if start_date:
+        success_query = success_query.filter(
+            models.TestRun.start_time > start_date)
+        fail_query = fail_query.filter(
+            models.TestRun.start_time > start_date)
+        skip_query = skip_query.filter(
+            models.TestRun.start_time > start_date)
+
+    if stop_date:
+        success_query = success_query.filter(
+            models.TestRun.stop_time < stop_date)
+        fail_query = fail_query.filter(
+            models.TestRun.stop_time < stop_date)
+        skip_query = skip_query.filter(
+            models.TestRun.stop_time < stop_date)
+
+    count_dict['success'] = success_query.count()
+    count_dict['failure'] = fail_query.count()
+    count_dict['skips'] = skip_query.count()
+    return count_dict
